.. highlight:: shell

============
Installation
============

This is a Python package, and it requires the ``pcbnew`` module included with KiCad.
Therefore, you'll have to install it using the ``pip`` executable included in the 
KiCad ``bin`` directory like so:

.. code-block:: console

    $ pip install kinet2pcb

This is the preferred method to install ``kinet2pcb``, as it will always install the most recent stable release.
